
package com.bd.framework.accessimpl;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.criterion.Order;

import com.bd.framework.accessapi.FindAllAccess;
import com.bd.framework.util.HibernateUtil;

/**
 * <p>
 * Find all entities of a specific type.
 * Implementation of Access command FindAllAccess. 
 * </p>
 * <p>
 * Command design pattern.
 * </p>
 */
public class FindAllAccessImpl<T> extends AccessBase 
    implements FindAllAccess<T> {
    
    private Class<T> persistentClass;

    private List<T> result;
    private String orderBy;
    private boolean orderByAsc = true;
    
    public FindAllAccessImpl(Class<T> persistentClass) {
        this.persistentClass = persistentClass;
    }
    
    protected Class<T> getPersistentClass() {
        return persistentClass;
    }

    public String getOrderBy() {
        return orderBy;
    }

    public void setOrderBy(String orderBy) {
        this.orderBy = orderBy;
    }

    public boolean isOrderByAsc() {
        return orderByAsc;
    }

    public void setOrderByAsc(boolean orderByAsc) {
        this.orderByAsc = orderByAsc;
    }
    
    public List<T> getResult() {
        return result;
    }
    
    @SuppressWarnings("unchecked")
    public void performExecute() throws HibernateException {
        Session session = HibernateUtil.currentSession();
        Criteria crit = session.createCriteria(getPersistentClass());
        
        if (orderBy != null) {
            if (orderByAsc) {
                crit.addOrder(Order.asc(orderBy));
            } else {
                crit.addOrder(Order.desc(orderBy));
            }
        }
        
        result = crit.list();
    }
    
    

} 