
package com.bd.framework.accessimpl;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.criterion.Example;
import org.hibernate.criterion.Order;

import com.bd.framework.accessapi.FindByExampleAccess;
import com.bd.framework.util.HibernateUtil;

/**
 * <p>
 * Find all entities similar to another entity.
 * Implementation of Access command FindByExampleAccess. 
 * </p>
 * <p>
 * Command design pattern.
 * </p>
 */
public class FindByExampleAccessImpl<T> extends AccessBase implements FindByExampleAccess<T> {

    private Class<T> persistentClass;
    
    private T exampleInstance;
    private String orderBy;
    private boolean orderByAsc = true;
    private String[] excludeProperties;
    private List<T> result;

    public FindByExampleAccessImpl(Class<T> persistentClass) {
        this.persistentClass = persistentClass;
    }
    
    protected Class<T> getPersistentClass() {
        return persistentClass;
    }
    
    public T getExample() {
        return exampleInstance;
    }

    public void setExample(T example) {
        this.exampleInstance = example;
    }
    
    public String getOrderBy() {
        return orderBy;
    }

    public void setOrderBy(String orderBy) {
        this.orderBy = orderBy;
    }

    public boolean isOrderByAsc() {
        return orderByAsc;
    }

    public void setOrderByAsc(boolean orderByAsc) {
        this.orderByAsc = orderByAsc;
    }


    public String[] getExcludeProperties() {
        return excludeProperties;
    }

    public void setExcludeProperties(String[] excludeProperties) {
        this.excludeProperties = excludeProperties;
    }

    public List<T> getResult() {
        return this.result;
    }

    @SuppressWarnings("unchecked")
    public void performExecute() throws HibernateException {
        Session session = HibernateUtil.currentSession();
        Example example = Example.create(exampleInstance).excludeZeroes().ignoreCase().enableLike();
        
        if (excludeProperties != null) {
            for (int i = 0; i < excludeProperties.length; i++) {
                example.excludeProperty(excludeProperties[i]);
            }
        }
        
        Criteria crit = session.createCriteria(getPersistentClass()).add(example);
        
        if (orderBy != null) {
            if (orderByAsc) {
                crit.addOrder(Order.asc(orderBy));
            } else {
                crit.addOrder(Order.desc(orderBy));
            }
        }
        
        result = crit.list();
    }
    
    

} 