
package com.bd.framework.accessimpl;
import com.bd.framework.accessapi.CreateAccess;
import com.bd.framework.accessapi.DeleteAccess;
import com.bd.framework.accessapi.FindByExampleAccess;
import com.bd.framework.accessapi.FindByIdAccess;
import com.bd.framework.accessapi.FindByQueryAccess;
import com.bd.framework.accessapi.GenericAccessFactory;
import com.bd.framework.accessapi.UpdateAccess;

/**
 * <p>
 * Concrete Factory that creates Generic Access objects. 
 * </p>
 * <p>
 * Abstract factory design pattern.
 * </p>
 *
 */
public class GenericAccessFactoryImpl<T> implements GenericAccessFactory<T> {

    private Class<T> persistentClass;
    
    public GenericAccessFactoryImpl(Class<T> persistentClass) {
        this.persistentClass = persistentClass;
    }
    
    public FindByIdAccess<T, String> createFindByIdAccess() {
        return new FindByIdAccessImpl<T, String>(persistentClass);
    }
     
    public CreateAccess<T> createCreateAccess() {
        return new CreateAccessImpl<T>();
    }
     
    public UpdateAccess<T> createUpdateAccess() {
        return new UpdateAccessImpl<T>();
    }
     
    public FindByQueryAccess<T> createFindByQueryAccess() {
        return new FindByQueryAccessImpl<T>();
    }
     
    public FindByExampleAccess<T> createFindByExampleAccess() {
        return new FindByExampleAccessImpl<T>(persistentClass);
    }
     
    public DeleteAccess<T> createDeleteAccess() {
        return new DeleteAccessImpl<T>();
    }
     


} 