
package com.bd.framework.accessimpl;

import org.hibernate.HibernateException;
import org.hibernate.Session;

import com.bd.framework.accessapi.UpdateAccess;
import com.bd.framework.util.HibernateUtil;

/**
 * <p>
 * Update an entity. It can save (create new) or update an entity.
 * Implementation of Access command for Update. 
 * </p>
 * <p>
 * Command design pattern.
 * </p>
 */
public class UpdateAccessImpl<T> extends AccessBase implements UpdateAccess<T> {

    private T entity;
    private boolean save = true;

    public boolean isSave() {
        return save;
    }

    public void setSave(boolean save) {
        this.save = save;
    }

    public T getEntity() {
        return entity;
    }

    public void setEntity(T entity) {
        this.entity = entity;
    }


    public void performExecute() throws HibernateException {
        Session session = HibernateUtil.currentSession();
        if (save) {
            session.saveOrUpdate(entity);
        } else {
            session.update(entity);
        }
    }


} 